@@ -1,5 +1,5 @@
-from traitlets import Unicode, Tuple, Bool
-from ipywidgets import register, DOMWidget 
+from traitlets import CUnicode, Unicode, Tuple, Bool
+from ipywidgets import register, DOMWidget
 from ._version import __version__
 
 
@@ -13,9 +13,11 @@ class Select2(DOMWidget):
     _view_module_version = Unicode(__version__).tag(sync=True)
     _model_module_version = Unicode(__version__).tag(sync=True)
 
-    value = Unicode('').tag(sync=True)
+    value = CUnicode(None).tag(sync=True)
+    values = Tuple(trait=Unicode('')).tag(sync=True)
     width = Unicode('').tag(sync=True)
     placeholder = Unicode('').tag(sync=True)
     multiple = Unicode('').tag(sync=True)
     options = Tuple(trait=Unicode('')).tag(sync=True)
     disabled = Bool(False).tag(sync=True)
+    lazy = Bool(False).tag(sync=True)
